referrerpolicy=no-referrer-when-downgrade

Inspect

Trait Inspect 

pub trait Inspect<AccountId>: Inspect<AccountId> {
    // Required methods
    fn name() -> Vec<u8> ;
    fn symbol() -> Vec<u8> ;
    fn decimals() -> u8;
}
Trait for inspecting fungible token metadata.

Required Methods

fn name() -> Vec<u8>

Returns the name of the token.

fn symbol() -> Vec<u8>

Returns the ticker symbol of the token.

fn decimals() -> u8

Returns the number of decimals this asset uses to represent one unit.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<F: Inspect<AccountId>, A: Get<<F as Inspect<AccountId>>::AssetId>, AccountId> Inspect<AccountId> for ItemOf<F, A, AccountId>

Adapter implementation of super::metadata::Inspect for ItemOf.

See the original trait documentation for information on item meaning and usage.