referrerpolicy=no-referrer-when-downgrade

Mutate

Trait Mutate 

pub trait Mutate<AccountId>: Inspect<AccountId> {
    // Required method
    fn set(
        from: &AccountId,
        name: Vec<u8>,
        symbol: Vec<u8>,
        decimals: u8,
    ) -> DispatchResult;
}
Trait for mutating fungible token metadata.

Required Methods

fn set( from: &AccountId, name: Vec<u8>, symbol: Vec<u8>, decimals: u8, ) -> DispatchResult

Set the name, symbol and decimals for the token.

  • from: The account of the asset’s owner from which the updated deposit will be reserved.
  • name: The new name.
  • symbol: The new ticker symbol.
  • decimals: The new number of decimals this asset uses to represent one unit.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<F: Mutate<AccountId>, A: Get<<F as Inspect<AccountId>>::AssetId>, AccountId> Mutate<AccountId> for ItemOf<F, A, AccountId>

Adapter implementation of super::metadata::Mutate for ItemOf.

See the original trait documentation for information on item meaning and usage.