pub trait Mutate<AccountId>: Inspect<AccountId> {
// Required method
fn set(
from: &AccountId,
name: Vec<u8>,
symbol: Vec<u8>,
decimals: u8,
) -> DispatchResult;
}Expand description
Trait for mutating fungible token metadata.
Required Methods
Sourcefn set(
from: &AccountId,
name: Vec<u8>,
symbol: Vec<u8>,
decimals: u8,
) -> DispatchResult
fn set( from: &AccountId, name: Vec<u8>, symbol: Vec<u8>, decimals: u8, ) -> DispatchResult
Set the name, symbol and decimals for the token.
from: The account of the asset’s owner from which the updated deposit will be reserved.name: The new name.symbol: The new ticker symbol.decimals: The new number of decimals this asset uses to represent one unit.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.